/*
 * Copyright (C) 2020-2021 Fairphone B.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.camera;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.util.Log;

public class CameraSwapBroadcastReceiver extends BroadcastReceiver {

    private static final String TAG = "CameraSwapReceiver";

    /**
     * Action to handle a change of camera(s).
     */
    private static final String ACTION_HANDLE_CAMERA_CHANGED =
            "com.fairphone.moduledetect.ACTION_HANDLE_CAMERA_CHANGED";

    private static final String EXTRA_FRONT_CAMERA_CHANGED =
            "com.fairphone.moduledetect.EXTRA_FRONT_CAMERA_CHANGED";

    private static final String EXTRA_REAR_CAMERA_CHANGED =
            "com.fairphone.moduledetect.EXTRA_REAR_CAMERA_CHANGED";

    /**
     * Preferences to be wiped after a Camera module swap.
     */
    private static final String PREFERENCE_TO_WIPE_CACHE_FRONT = "CachedSupportedPictureSizes_Build_Camera1";
    private static final String PREFERENCE_TO_WIPE_RES_FRONT = "pref_camera_picturesize_front_key";
    private static final String PREFERENCE_TO_WIPE_CACHE_REAR = "CachedSupportedPictureSizes_Build_Camera0";
    private static final String PREFERENCE_TO_WIPE_RES_REAR = "pref_camera_picturesize_back_key";

    @Override
    public void onReceive(Context context, Intent intent) {
        if (!ACTION_HANDLE_CAMERA_CHANGED.equals(intent.getAction())) {
            return;
        }
        Log.i(TAG, "Received broadcast: " + ACTION_HANDLE_CAMERA_CHANGED);
        wipeCameraPreferences(context, intent);
    }

    private void wipeCameraPreferences(Context context, Intent intent) {
        boolean hasFrontCameraChanged = intent.getBooleanExtra(EXTRA_FRONT_CAMERA_CHANGED, false);
        boolean hasRearCameraChanged = intent.getBooleanExtra(EXTRA_REAR_CAMERA_CHANGED, false);

        if (hasFrontCameraChanged) {
            wipeFrontCameraPreferences(context);
        }
        if (hasRearCameraChanged) {
            wipeRearCameraPreferences(context);
        }
    }

    private void wipeFrontCameraPreferences(Context context) {
        Log.i(TAG, "Wiping front camera preferences");
        SharedPreferences.Editor editor = PreferenceManager.getDefaultSharedPreferences(context).edit();
        editor.remove(PREFERENCE_TO_WIPE_CACHE_FRONT);
        editor.remove(PREFERENCE_TO_WIPE_RES_FRONT);
        editor.apply();
    }

    private void wipeRearCameraPreferences(Context context) {
        Log.i(TAG, "Wiping rear camera preferences");
        SharedPreferences.Editor editor = PreferenceManager.getDefaultSharedPreferences(context).edit();
        editor.remove(PREFERENCE_TO_WIPE_CACHE_REAR);
        editor.remove(PREFERENCE_TO_WIPE_RES_REAR);
        editor.apply();
    }
}
